<p align="center">
<img src="./mazeai.png" alt="maze ai" width=80>
<h3 align="center">MAZE AI</h3>
<p align="center">
人工智能辅助药物设计工具集合
</p>
</p>

<p align="center">
<a href="https://pypi.org/project/mazeai/"><img src="https://img.shields.io/pypi/v/mazeai" alt="pypi version"/></a>
</p>

![Conda Version](https://img.shields.io/conda/v/mazeai/mazeai.svg)

## 前言

## 环境安装

## 其他
